@@ -1,21 +1,22 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014, Pall Sigurdsson <palli@opensource.is>
+# Adagios is a web based Nagios configuration interface
 #
-# This script is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Copyright (C) 2014, Pall Sigurdsson <palli@opensource.is>
 #
-# This script is distributed in the hope that it will be useful,
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
 from django.core.context_processors import csrf
 from django.shortcuts import render_to_response
 from django.shortcuts import HttpResponse
@@ -27,6 +28,7 @@ from adagios.views import adagios_decorator, error_page
 from django.template import RequestContext
 from adagios.contrib import get_template_name
 from django import template
+from django.utils.translation import ugettext as _
 
 
 @adagios_decorator
@@ -40,7 +42,7 @@ def index(request, contrib_dir=None):
     views = os.listdir(contrib_dir)
 
     if not views:
-        errors.append("Directory '%s' is empty" % contrib_dir)
+        errors.append(_("Directory '%s' is empty") % contrib_dir)
     return render_to_response("contrib_index.html", locals(), context_instance=RequestContext(request))
 
 
