@@ -1,4 +1,21 @@
 #!/usr/bin/python
+#
+# Adagios is a web based Nagios configuration interface
+#
+# Copyright (C) 2014, Pall Sigurdsson <palli@opensource.is>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
@@ -16,6 +33,7 @@ from pynag import Utils
 from pynag import __version__
 from socket import gethostbyname_ex
 import adagios.settings
+from django.utils.translation import ugettext as _
 
 
 #_config = Parsers.config(adagios.settings.nagios_config)
@@ -144,13 +162,13 @@ def change_service_attribute(identifier, new_value):
     tmp = identifier.split('::')
     if len(tmp) != 3:
         raise ValueError(
-            "identifier must be in the form of host_name::service_description::attribute_name (got %s)" % identifier)
+            _("identifier must be in the form of host_name::service_description::attribute_name (got %s)") % identifier)
     host_name, service_description, attribute_name = tmp
     try:
         service = Model.Service.objects.get_by_shortname(
             "%s/%s" % (host_name, service_description))
     except KeyError, e:
-        raise KeyError("Could not find service %s" % e)
+        raise KeyError(_("Could not find service %s") % e)
     service[attribute_name] = new_value
     service.save()
     return True
@@ -172,7 +190,7 @@ def copy_object(object_id, recursive=False, **kwargs):
     """
     o = Model.ObjectDefinition.objects.get_by_id(object_id)
     new_object = o.copy(recursive=recursive, **kwargs)
-    return "Object successfully copied to %s" % new_object.get_filename()
+    return _("Object successfully copied to %s") % new_object.get_filename()
 
 
 def run_check_command(object_id):
@@ -184,7 +202,7 @@ def run_check_command(object_id):
         [return_code,stdout,stderr]
     """
     if platform.node() == 'adagios.opensource.is':
-        return 1, 'Running check commands is disabled in demo-environment'
+        return 1, _('Running check commands is disabled in demo-environment')
     o = Model.ObjectDefinition.objects.get_by_id(object_id)
     return o.run_check_command()
 
@@ -229,11 +247,11 @@ def reload_nagios():
     )
     result = {}
     if daemon.reload() == 0:
-        result['status'] = "success"
-        result['message'] = 'Nagios Successfully reloaded'
+        result['status'] = _("success")
+        result['message'] = _('Nagios Successfully reloaded')
     else:
-        result['status'] = "error"
-        result['message'] = "Failed to reload nagios (do you have enough permissions?)"
+        result['status'] = _("error")
+        result['message'] = _("Failed to reload nagios (do you have enough permissions?)")
     return result
 
 
