@@ -1,24 +1,27 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010, Pall Sigurdsson <palli@opensource.is>
+# Adagios is a web based Nagios configuration interface
 #
-# This script is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Copyright (C) 2010, Pall Sigurdsson <palli@opensource.is>
 #
-# This script is distributed in the hope that it will be useful,
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from django.core.context_processors import csrf
 from django.forms.formsets import BaseFormSet
 from django.shortcuts import render_to_response
 from django.shortcuts import render
+from django.utils.translation import ugettext as _
 
 from django.shortcuts import HttpResponse
 from django.template import RequestContext
@@ -71,11 +74,11 @@ def settings(request):
         if form.is_valid():
             try:
                 form.save()
-                m.append("%s successfully saved." % form.adagios_configfile)
+                m.append(_("%s successfully saved.") % form.adagios_configfile)
             except IOError, exc:
                 e.append(exc)
     else:
-        raise Exception("We only support methods GET or POST")
+        raise Exception(_("We only support methods GET or POST"))
     c['form'] = form
     return render_to_response('settings.html', c, context_instance=RequestContext(request))
 
@@ -116,16 +119,16 @@ def gitlog(request):
             elif 'git_commit' in request.POST:
                 filelist = []
                 commit_message = request.POST.get(
-                    'git_commit_message', "bulk commit by adagios")
+                    'git_commit_message', _("bulk commit by adagios"))
                 for i in request.POST:
                     if i.startswith('commit_'):
                         filename = i[len('commit_'):]
                         git.add(filename)
                         filelist.append(filename)
                 if len(filelist) == 0:
-                    raise Exception("No files selected.")
+                    raise Exception(_("No files selected."))
                 git.commit(message=commit_message, filelist=filelist)
-                m.append("%s files successfully commited." % len(filelist))
+                m.append(_("%s files successfully commited.") % len(filelist))
         except Exception, e:
             c['errors'].append(e)
     # Check if nagiosdir has a git repo or not
@@ -227,22 +230,22 @@ def pnp4nagios(request):
             data=request.POST)
         if broker_form.is_valid():
             broker_form.save()
-            m.append("Broker Module updated in nagios.cfg")
+            m.append(_("Broker Module updated in nagios.cfg"))
     elif request.method == 'POST' and 'save_action_url' in request.POST:
         c['action_url'] = forms.PNPActionUrlForm(data=request.POST)
         if c['action_url'].is_valid():
             c['action_url'].save()
-            m.append('Action_url updated for %s services' %
+            m.append(_('Action_url updated for %s services') %
                      c['action_url'].total_services)
             if c['action_url'].error_services > 0:
                 e.append(
-                    "%s services could not be updated (check permissions?)" %
+                    _("%s services could not be updated (check permissions?)") %
                     c['action_url'].error_services)
     elif request.method == 'POST' and 'save_npcd_config' in request.POST:
         c['npcd_config'] = forms.PNPConfigForm(data=request.POST)
         if c['npcd_config'].is_valid():
             c['npcd_config'].save()
-            m.append("npcd.cfg updated")
+            m.append(_("npcd.cfg updated"))
 
     return render_to_response('pnp4nagios.html', c, context_instance=RequestContext(request))
 
@@ -289,7 +292,7 @@ def pnp4nagios_edit_template(request, filename):
         return edit_file(request, filename=filename)
     else:
         raise Exception(
-            "Security violation. You are not allowed to edit %s" % filename)
+            _("Security violation. You are not allowed to edit %s") % filename)
 
 
 @adagios_decorator
@@ -322,7 +325,7 @@ def icons(request, image_name=None):
             fsock = open("%s/%s" % (image_path, image_name,))
             return HttpResponse(fsock, mimetype=mime_type)
         else:
-            raise Exception("Not allowed to see this image")
+            raise Exception(_("Not allowed to see this image"))
 
 
 @adagios_decorator
@@ -355,12 +358,12 @@ def mail(request):
         host_object = adagios.status.utils.get_hosts(request, host_name=host_name)
         if not host_object:
             c['errors'].append(
-                "Host %s not found. Maybe a typo or you do not have access to it." % host_name
+                _("Host %s not found. Maybe a typo or you do not have access to it.") % host_name
             )
             continue
         for item in host_object:
             item['host_name'] = item['name']
-            item['description'] = "Host Status"
+            item['description'] = _("Host Status")
             c['form'].status_objects.append(item)
             c['form'].hosts.append(item)
 
@@ -373,14 +376,14 @@ def mail(request):
                                                         )
             if not service:
                 c['errors'].append(
-                    'Service "%s"" not found. Maybe a typo or you do not have access to it ?' % i)
+                    _('Service "%s"" not found. Maybe a typo or you do not have access to it ?') % i)
             for x in service:
                 c['form'].status_objects.append(x)
                 c['form'].services.append(x)
         except AttributeError, e:
-            c['errors'].append("AttributeError for '%s': %s" % (i, e))
+            c['errors'].append(_("AttributeError for '%(i)s': %(e)s") % {'i': i, 'e': e})
         except KeyError, e:
-            c['errors'].append("Error adding service '%s': %s" % (i, e))
+            c['errors'].append(_("Error adding service '%(i)s': %(e)s") % {'i': i, 'e': e})
 
     c['services'] = c['form'].services
     c['hosts'] = c['form'].hosts
@@ -391,49 +394,6 @@ def mail(request):
         c['form'].save()
     return render_to_response('misc_mail.html', c, context_instance=RequestContext(request))
 
-def get_access_level(request):
-    """ Return the access level of current user.
-
-    Returns the following in order:
-        "administrator" - if user is an belongs to administrators group
-        "operator" - if user belongs to operators group
-        "auditor" - if user belongs to auditors group
-        "contact" - if user is defined as a contact
-        None - if user is not defined at all
-
-    """
-    user = request.META.get('REMOTE_USER', 'anonymous')
-    admins = adagios.settings.administrators.split(',')
-    operators = adagios.settings.operators.split(',')
-    auditors = adagios.settings.auditors.split(',')
-
-    if user in admins:
-        return "administrator"
-    if user in operators:
-        return "operator"
-    if user in auditors:
-        return "auditor"
-
-    # Check if this user has any contactgroups that grant him privileges
-    contactgroups = adagios.status.utils.get_contactgroups(
-        request,
-        'Columns: name',
-        'Filter: members >= %s' % user,
-    )
-    for group in contactgroups:
-        group_name = group['name']
-        if group_name in admins:
-            return "administrator"
-        if group_name in operators:
-            return "operator"
-        if group_name in auditors:
-            return "auditor"
-
-    # Check if this user is defined as a contact
-    contacts = adagios.status.utils.get_contacts(request, name=user)
-    if contacts:
-        return "contact"
-    return None
 
 
 @adagios_decorator
@@ -445,8 +405,6 @@ def test(request):
     c.update(csrf(request))
     # Get some test data
 
-    print "you are: ", get_access_level(request)
-
     if request.method == 'POST':
         c['form'] = forms.PluginOutputForm(data=request.POST)
         if c['form'].is_valid():
