@@ -1,3 +1,20 @@
+# Adagios is a web based Nagios configuration interface
+#
+# Copyright (C) 2014, Pall Sigurdsson <palli@opensource.is>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+# 
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 # Django settings for adagios project.
 
 DEBUG = True
@@ -76,13 +93,24 @@ TEMPLATE_LOADERS = (
 )
 
 MIDDLEWARE_CLASSES = (
-    'django.middleware.common.CommonMiddleware',
     #'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.locale.LocaleMiddleware',
+    'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
+    'adagios.auth.AuthorizationMiddleWare',
     #'django.contrib.auth.middleware.AuthenticationMiddleware',
     #'django.contrib.messages.middleware.MessageMiddleware',
 )
 
+LANGUAGES = (
+    ('en', 'English'),
+    ('fr', 'French'),
+)
+
+LOCALE_PATHS = (
+    "%s/locale/" % (djangopath),
+)
+
 ROOT_URLCONF = 'adagios.urls'
 
 TEMPLATE_DIRS = (
@@ -118,7 +146,22 @@ TEMPLATE_CONTEXT_PROCESSORS = ('adagios.context_processors.on_page_load',
     "django.core.context_processors.request",
     "django.contrib.messages.context_processors.messages")
 
- 
+
+# Themes options #
+# To rapidly switch your theme, update THEME_DEFAULT and leave the rest.
+
+# folders in which themes files will be looked up
+THEMES_FOLDER = 'themes' # in 'media/'
+
+# default theme in use, it should be present in the THEMES_FOLDER
+# (or at least through a symbolic link)
+THEME_DEFAULT = 'default'
+
+# CSS entry-point, in the theme folder
+THEME_ENTRY_POINT = 'style.css'
+
+# generated location of
+THEME_CSS = os.path.join(THEMES_FOLDER, THEME_DEFAULT, THEME_ENTRY_POINT)
 
 
 # Adagios specific configuration options. These are just the defaults,
