@@ -1,3 +1,20 @@
+# Adagios is a web based Nagios configuration interface
+#
+# Copyright (C) 2014, Pall Sigurdsson <palli@opensource.is>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+# 
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 from django.conf.urls.defaults import *
 from django.conf import settings
 
@@ -13,7 +30,7 @@ urlpatterns = patterns('adagios',
                         url(r'^/downtimes/?$', 'status.views.downtime_list'),
                         url(r'^/hostgroups/?$', 'status.views.status_hostgroups'),
                         url(r'^/hosts/?$', 'status.views.hosts'),
-                        url(r'^/log/?$', 'status.views.status_log'),
+                        url(r'^/log/?$', 'status.views.log'),
                         url(r'^/map/?', 'status.views.map_view'),
                         url(r'^/parents/?$', 'status.views.network_parents'),
                         url(r'^/perfdata/?$', 'status.views.perfdata'),
