@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010, Pall Sigurdsson <palli@opensource.is>
+# Adagios is a web based Nagios configuration interface
 #
-# This script is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Copyright (C) 2010, Pall Sigurdsson <palli@opensource.is>
 #
-# This script is distributed in the hope that it will be useful,
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 from django.http import HttpResponse
 
 import time
@@ -26,6 +29,7 @@ from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
 from django.utils.encoding import smart_str
 from django.core.context_processors import csrf
+from django.utils.translation import ugettext as _
 
 import pynag.Model
 import pynag.Utils
@@ -72,7 +76,7 @@ def detail(request):
     elif servicegroup_name:
         return servicegroup_detail(request, servicegroup_name=servicegroup_name)
 
-    raise Exception("You have to provide an item via querystring so we know what to give you details for")
+    raise Exception(_("You have to provide an item via querystring so we know what to give you details for"))
 
 
 @adagios_decorator
@@ -204,7 +208,7 @@ def snippets_log(request):
     elif host_name:
         object_type = "host"
     else:
-        raise Exception("Need either a host_name or hostgroup_name parameter")
+        raise Exception(_("Need either a host_name or hostgroup_name parameter"))
 
     c = {'log':log}
     c['object_type'] = object_type
@@ -258,13 +262,13 @@ def service_detail(request, host_name, service_description):
         my_host['object_type'] = 'host'
         my_host['short_name'] = my_host['name']
     except IndexError:
-        c['errors'].append("Could not find any host named '%s'" % host_name)
+        c['errors'].append(_("Could not find any host named '%s'") % host_name)
         return error_page(request, c)
 
     if service_description is None:
         tmp = request.GET.get('service_description')
         if tmp is not None:
-            return status_detail(request, host_name, service_description=tmp)
+            return service_detail(request, host_name, service_description=tmp)
         primary_object = my_host
         c['service_description'] = '_HOST_'
         #c['log'] = pynag.Parsers.LogFiles(maincfg=adagios.settings.nagios_config).get_state_history(
@@ -282,7 +286,7 @@ def service_detail(request, host_name, service_description):
             #    host_name=host_name, service_description=service_description)
         except IndexError:
             c['errors'].append(
-                "Could not find any service named '%s'" % service_description)
+                _("Could not find any service named '%s'") % service_description)
             return error_page(request, c)
 
     c['my_object'] = primary_object
@@ -396,7 +400,6 @@ def hostgroup_detail(request, hostgroup_name):
     return render_to_response('status_hostgroup.html', c, context_instance=RequestContext(request))
 
 
-@adagios_decorator
 def _add_statistics_to_hostgroups(hostgroups):
     """ Enriches a list of hostgroup dicts with information about subgroups and parentgroups
     """
@@ -777,14 +780,15 @@ def state_history(request):
     end_time = request.GET.get('end_time', None)
     if end_time is None:
         end_time = time.time()
-    end_time = int(end_time)
+    end_time = int(float(end_time))
     if start_time is None:
         seconds_in_a_day = 60 * 60 * 24
         seconds_today = end_time % seconds_in_a_day  # midnight of today
         start_time = end_time - seconds_today
     start_time = int(start_time)
+
     l = pynag.Parsers.LogFiles(maincfg=adagios.settings.nagios_config)
-    c['log'] = log = l.get_state_history()
+    c['log'] = log = l.get_state_history(start_time=start_time, end_time=end_time,strict=False)
     total_duration = end_time - start_time
     c['total_duration'] = total_duration
     css_hint = {}
@@ -795,24 +799,30 @@ def state_history(request):
     last_item = None
 
     services = {}
+    search_filter = request.GET.copy()
+    search_filter.pop('start_time', None)
+    search_filter.pop('end_time', None)
+    search_filter.pop('start_time_picker', None)
+    search_filter.pop('start_hours', None)
+    search_filter.pop('end_time_picker', None)
+    search_filter.pop('end_hours', None)
+    search_filter.pop('submit', None)
+
+    log = pynag.Utils.grep(log, **search_filter)
     for i in log:
         short_name = "%s/%s" % (i['host_name'], i['service_description'])
-        for k, v in request.GET.items():
-            if k in i.keys() and i[k] != v:
-                break
-        else:
-            if short_name not in services:
-                s = {}
-                s['host_name'] = i['host_name']
-                s['service_description'] = i['service_description']
-                s['log'] = []
-                s['worst_logfile_state'] = 0
-                #s['log'] = [{'time':start_time,'state':3, 'plugin_output':'Unknown value here'}]
-                services[short_name] = s
+        if short_name not in services:
+            s = {}
+            s['host_name'] = i['host_name']
+            s['service_description'] = i['service_description']
+            s['log'] = []
+            s['worst_logfile_state'] = 0
+            #s['log'] = [{'time':start_time,'state':3, 'plugin_output':'Unknown value here'}]
+            services[short_name] = s
 
-            services[short_name]['log'].append(i)
-            services[short_name]['worst_logfile_state'] = max(
-                services[short_name]['worst_logfile_state'], i['state'])
+        services[short_name]['log'].append(i)
+        services[short_name]['worst_logfile_state'] = max(
+            services[short_name]['worst_logfile_state'], i['state'])
     for service in services.values():
         last_item = None
         service['sla'] = float(0)
@@ -845,7 +855,6 @@ def state_history(request):
                 service['sla'] += last_item['duration_percent']
             else:
                 service['num_problems'] += 1
-
     c['services'] = services
     c['start_time'] = start_time
     c['end_time'] = end_time
@@ -912,7 +921,7 @@ def _status_log(request):
 
 
 @adagios_decorator
-def status_log(request):
+def log(request):
     c = _status_log(request)
     c['request'] = request
     c['log'].reverse()
@@ -979,10 +988,7 @@ def contact_list(request):
     c = {}
     c['messages'] = []
     c['errors'] = []
-    l = adagios.status.utils.livestatus(request)
-    c['contacts'] = l.query('GET contacts')
-    c['contacts'] = pynag.Utils.grep(c['contacts'], **request.GET)
-    c['contactgroups'] = l.query('GET contactgroups')
+    c['contacts'] = adagios.status.utils.get_contacts(request, **request.GET)
     return render_to_response('status_contacts.html', c, context_instance=RequestContext(request))
 
 
@@ -1178,4 +1184,4 @@ def status_hostgroup(request, hostgroup_name):
 @adagios_decorator
 def status_detail(request):
     """ Here for backwards compatibility """
-    return detail(request)
\ No newline at end of file
+    return detail(request)
